Common class abstract
- Common is a base class providing common validation functionalities.
- Implementers
Constructors
- Common()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
valid(
dynamic value, MapEntry< String, Validate> validate) → dynamic
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited