Decimal class

  • This is a top level data type class for double data type.
Inheritance

Constructors

Decimal(TypeProperty property)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stack → List<Stack>
finalinherited

Methods

max(double max) → Max
min(double min) → Min
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
only(List<int> allow) → Only
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited