Email class
- This is a top level data type class for valid Email.
Constructors
- Email(TypeProperty property)
Properties
Methods
-
mustEnd(
List< String> allow) → MustEnd -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited