ObjType enum

Defines various object types for validation purposes.

Inheritance
Available extensions

Values

str → const ObjType
integer → const ObjType
boolean → const ObjType
decimal → const ObjType
datetime → const ObjType
email → const ObjType
min → const ObjType
max → const ObjType
len → const ObjType
only → const ObjType
mustend → const ObjType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ObjType>
A constant List of the values in this enum, in order of their declaration.