TypeProperty class
- TypeProperty defines properties for types, including nullability and default null value.
Constructors
- TypeProperty(bool nullAble, dynamic nullValue)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited