Max class

  • Max adds a maximum constraint to the validation stack.
Inheritance

Constructors

Max(dynamic max, List<Stack> stack)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stack → List<Stack>
finalinherited

Methods

min(dynamic min) → Min
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited