VResult class

  • VResult represents the result of a validation process, including error status, message, and data.

Constructors

VResult({required bool error, required String message, required Map<String, dynamic> data})

Properties

data → Map<String, dynamic>
final
error → bool
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fail(String errorMessage) → VResult
ok(Map<String, dynamic> data) → VResult