menu
data_validation package
documentation
data_types.dart
Datetime class
Datetime class
dark_mode
light_mode
Datetime
class
This is a top level data type class for
DateTime
data type.
Inheritance
Object
Validate
Datetime
Constructors
Datetime
(
TypeProperty
property
)
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
stack
→
List
<
Stack
>
final
inherited
Methods
max
(
DateTime
max
)
→
Max
min
(
DateTime
min
)
→
Min
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
only
(
List
<
DateTime
>
allow
)
→
Only
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
data_validation package
documentation
data_types
Datetime class
data_types library