menu
data_validation package
documentation
data_types.dart
Str class
Str class
dark_mode
light_mode
Str
class
This is a top level data type class for
String
data type.
Inheritance
Object
Validate
Str
Constructors
Str
(
TypeProperty
property
)
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
stack
→
List
<
Stack
>
final
inherited
Methods
length
(
int
len
)
→
Max
max
(
int
max
)
→
Max
min
(
int
min
)
→
Min
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
only
(
List
<
String
>
allow
)
→
Only
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
data_validation package
documentation
data_types
Str class
data_types library